@@ -104,7 +104,7 @@ class AmsClient(AbstractClient):
         ### 接口功能说明：
         - 支持对音频流或音频文件进行检测，判断其中是否包含违规内容；
         - 支持设置回调地址 Callback 获取检测结果（对于已在审核的任务，最长回调时间为用户配置的**切片时长 + 2s**），或通过接口(查询音频检测结果)主动轮询获取检测结果；
-        - 支持识别违规内容，包括：低俗、谩骂、色情、涉政、广告等场景；
+        - 支持识别违规内容，包括：低俗、谩骂、色情、广告等场景；
         - 支持批量提交检测任务，检测任务列表**最多支持10个**。
 
         ### 音频文件调用说明：
