@@ -26,6 +26,34 @@ class CiiClient(AbstractClient):
     _service = 'cii'
 
 
+    def CreateAutoClassifyStructureTask(self, request):
+        """本接口(CreateAutoClassifyStructureTask)基于提供的客户及保单信息，创建并启动结构化识别任务。
+
+        :param request: Request instance for CreateAutoClassifyStructureTask.
+        :type request: :class:`tencentcloud.cii.v20210408.models.CreateAutoClassifyStructureTaskRequest`
+        :rtype: :class:`tencentcloud.cii.v20210408.models.CreateAutoClassifyStructureTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateAutoClassifyStructureTask", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateAutoClassifyStructureTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateStructureTask(self, request):
         """本接口(CreateStructureTask)基于提供的客户及保单信息，创建并启动结构化识别任务。
 
@@ -54,20 +82,48 @@ class CiiClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def CreateStructureTaskTest(self, request):
-        """本接口(CreateStructureTaskTest)基于提供的客户及保单信息，创建并启动结构化识别任务。用于路由到测试环境。
+    def CreateUnderwriteTaskById(self, request):
+        """本接口(CreateUnderwriteTaskById)用于根据结构化任务ID创建核保任务
 
-        :param request: Request instance for CreateStructureTaskTest.
-        :type request: :class:`tencentcloud.cii.v20210408.models.CreateStructureTaskTestRequest`
-        :rtype: :class:`tencentcloud.cii.v20210408.models.CreateStructureTaskTestResponse`
+        :param request: Request instance for CreateUnderwriteTaskById.
+        :type request: :class:`tencentcloud.cii.v20210408.models.CreateUnderwriteTaskByIdRequest`
+        :rtype: :class:`tencentcloud.cii.v20210408.models.CreateUnderwriteTaskByIdResponse`
 
         """
         try:
             params = request._serialize()
-            body = self.call("CreateStructureTaskTest", params)
+            body = self.call("CreateUnderwriteTaskById", params)
             response = json.loads(body)
             if "Error" not in response["Response"]:
-                model = models.CreateStructureTaskTestResponse()
+                model = models.CreateUnderwriteTaskByIdResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeMachineUnderwrite(self, request):
+        """本接口(DescribeMachineUnderwrite)用于查询机器核保任务数据
+
+        :param request: Request instance for DescribeMachineUnderwrite.
+        :type request: :class:`tencentcloud.cii.v20210408.models.DescribeMachineUnderwriteRequest`
+        :rtype: :class:`tencentcloud.cii.v20210408.models.DescribeMachineUnderwriteResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeMachineUnderwrite", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeMachineUnderwriteResponse()
                 model._deserialize(response["Response"])
                 return model
             else:
@@ -110,6 +166,34 @@ class CiiClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeStructureDifference(self, request):
+        """结构化复核差异查询接口，对比结构化复核前后数据差异，返回差异的部分。
+
+        :param request: Request instance for DescribeStructureDifference.
+        :type request: :class:`tencentcloud.cii.v20210408.models.DescribeStructureDifferenceRequest`
+        :rtype: :class:`tencentcloud.cii.v20210408.models.DescribeStructureDifferenceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeStructureDifference", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeStructureDifferenceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeStructureResult(self, request):
         """本接口(DescribeStructureResult)用于查询结构化结果接口
 
@@ -166,20 +250,21 @@ class CiiClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeStructureTaskResultTest(self, request):
-        """依据任务ID获取结构化结果接口，该接口用于路由到测试环境。
+    def UploadMedicalFile(self, request):
+        """上传医疗影像文件，可以用来做结构化。
 
-        :param request: Request instance for DescribeStructureTaskResultTest.
-        :type request: :class:`tencentcloud.cii.v20210408.models.DescribeStructureTaskResultTestRequest`
-        :rtype: :class:`tencentcloud.cii.v20210408.models.DescribeStructureTaskResultTestResponse`
+        :param request: Request instance for UploadMedicalFile.
+        :type request: :class:`tencentcloud.cii.v20210408.models.UploadMedicalFileRequest`
+        :rtype: :class:`tencentcloud.cii.v20210408.models.UploadMedicalFileResponse`
 
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeStructureTaskResultTest", params)
+            options = {'IsMultipart': True, 'BinaryParams': [u'File']}
+            body = self.call("UploadMedicalFile", params, options=options)
             response = json.loads(body)
             if "Error" not in response["Response"]:
-                model = models.DescribeStructureTaskResultTestResponse()
+                model = models.UploadMedicalFileResponse()
                 model._deserialize(response["Response"])
                 return model
             else:
