@@ -110,62 +110,6 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def CreateAsyncContextTask(self, request):
-        """本接口用于创建离线上下文任务
-
-        :param request: Request instance for CreateAsyncContextTask.
-        :type request: :class:`tencentcloud.cls.v20201016.models.CreateAsyncContextTaskRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.CreateAsyncContextTaskResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("CreateAsyncContextTask", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateAsyncContextTaskResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def CreateAsyncSearchTask(self, request):
-        """本接口用于创建离线检索任务
-
-        :param request: Request instance for CreateAsyncSearchTask.
-        :type request: :class:`tencentcloud.cls.v20201016.models.CreateAsyncSearchTaskRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.CreateAsyncSearchTaskResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("CreateAsyncSearchTask", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateAsyncSearchTaskResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def CreateConfig(self, request):
         """创建采集规则配置
 
@@ -194,6 +138,34 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateConsumer(self, request):
+        """本接口用于创建投递任务
+
+        :param request: Request instance for CreateConsumer.
+        :type request: :class:`tencentcloud.cls.v20201016.models.CreateConsumerRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.CreateConsumerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateConsumer", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateConsumerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateExport(self, request):
         """本接口用于创建日志下载任务
 
@@ -418,62 +390,6 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DeleteAsyncContextTask(self, request):
-        """本接口用于删除离线上下文任务
-
-        :param request: Request instance for DeleteAsyncContextTask.
-        :type request: :class:`tencentcloud.cls.v20201016.models.DeleteAsyncContextTaskRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.DeleteAsyncContextTaskResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DeleteAsyncContextTask", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DeleteAsyncContextTaskResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DeleteAsyncSearchTask(self, request):
-        """本接口用于删除离线检索任务
-
-        :param request: Request instance for DeleteAsyncSearchTask.
-        :type request: :class:`tencentcloud.cls.v20201016.models.DeleteAsyncSearchTaskRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.DeleteAsyncSearchTaskResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DeleteAsyncSearchTask", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DeleteAsyncSearchTaskResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DeleteConfig(self, request):
         """删除采集规则配置
 
@@ -530,6 +446,34 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteConsumer(self, request):
+        """本接口用于删除投递配置
+
+        :param request: Request instance for DeleteConsumer.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DeleteConsumerRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DeleteConsumerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteConsumer", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteConsumerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteExport(self, request):
         """本接口用于删除日志下载任务
 
@@ -754,118 +698,6 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeAsyncContextResult(self, request):
-        """本接口用户获取离线上下文任务的结果
-
-        :param request: Request instance for DescribeAsyncContextResult.
-        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncContextResultRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncContextResultResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeAsyncContextResult", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeAsyncContextResultResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeAsyncContextTasks(self, request):
-        """本接口用于获取离线上下文任务列表
-
-        :param request: Request instance for DescribeAsyncContextTasks.
-        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncContextTasksRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncContextTasksResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeAsyncContextTasks", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeAsyncContextTasksResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeAsyncSearchResult(self, request):
-        """本接口用户获取离线检索任务的结果
-
-        :param request: Request instance for DescribeAsyncSearchResult.
-        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncSearchResultRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncSearchResultResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeAsyncSearchResult", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeAsyncSearchResultResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeAsyncSearchTasks(self, request):
-        """本接口用户获取离线检索任务列表
-
-        :param request: Request instance for DescribeAsyncSearchTasks.
-        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncSearchTasksRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncSearchTasksResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeAsyncSearchTasks", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeAsyncSearchTasksResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DescribeConfigMachineGroups(self, request):
         """获取采集规则配置所绑定的机器组
 
@@ -922,6 +754,34 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeConsumer(self, request):
+        """本接口用于获取投递配置
+
+        :param request: Request instance for DescribeConsumer.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeConsumerRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeConsumerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeConsumer", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeConsumerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeExports(self, request):
         """本接口用于获取日志下载任务列表
 
@@ -1370,6 +1230,34 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyConsumer(self, request):
+        """本接口用于修改投递任务
+
+        :param request: Request instance for ModifyConsumer.
+        :type request: :class:`tencentcloud.cls.v20201016.models.ModifyConsumerRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.ModifyConsumerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyConsumer", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyConsumerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyIndex(self, request):
         """本接口用于修改索引配置
 
