@@ -356,6 +356,9 @@ REQUESTLIMITEXCEEDED_REQUESTLIMITEXCEEDED = 'RequestLimitExceeded.RequestLimitEx
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
+# 没有域名别名。
+RESOURCENOTFOUND_NODATAOFDOMAINALIAS = 'ResourceNotFound.NoDataOfDomainAlias'
+
 # 记录列表为空。
 RESOURCENOTFOUND_NODATAOFRECORD = 'ResourceNotFound.NoDataOfRecord'
 
