@@ -14,6 +14,9 @@
 # limitations under the License.
 
 
+# 鉴权失败，当前用户不允许执行该操作。
+AUTHFAILURE_UNAUTHORIZEDOPERATIONERROR = 'AuthFailure.UnauthorizedOperationError'
+
 # 禁止该操作。
 FAILEDOPERATION_NOTALLOWOPERATION = 'FailedOperation.NotAllowOperation'
 
@@ -47,9 +50,18 @@ INTERNALERROR_LOCKERROR = 'InternalError.LockError'
 # 通信协议错误。
 INTERNALERROR_PROTOCOLERROR = 'InternalError.ProtocolError'
 
+# 内部错误。
+INTERNALERROR_UNDEFINEDERROR = 'InternalError.UndefinedError'
+
+# 未知的内部错误。
+INTERNALERROR_UNKNOWNERROR = 'InternalError.UnknownError'
+
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 参数值错误。
+INVALIDPARAMETER_BIZINVALIDPARAMETERVALUEERROR = 'InvalidParameter.BizInvalidParameterValueError'
+
 # 实例不存在。
 INVALIDPARAMETER_INSTANCENOTFOUND = 'InvalidParameter.InstanceNotFound'
 
@@ -74,6 +86,9 @@ OPERATIONDENIED_OPERATIONDENIED = 'OperationDenied.OperationDenied'
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
+# 未找到资源。
+RESOURCENOTFOUND_BIZRESOURCENOTFOUNDERROR = 'ResourceNotFound.BizResourceNotFoundError'
+
 # 迁移任务不存在。
 RESOURCENOTFOUND_JOBNOTEXIST = 'ResourceNotFound.JobNotExist'
 
