@@ -53,6 +53,9 @@ LIMITEXCEEDED_APPLICATION = 'LimitExceeded.Application'
 # 缺少参数。
 MISSINGPARAMETER_ = 'MissingParameter.'
 
+# 操作被拒绝。
+OPERATIONDENIED = 'OperationDenied'
+
 # 资源不足。
 RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 
