@@ -384,7 +384,7 @@ class GmeClient(AbstractClient):
         <h4><b>接口功能说明：</b></h4>
         <li>支持对语音流或语音文件进行检测，判断其中是否包含违规内容。</li>
         <li>支持设置回调地址 Callback 获取检测结果，同时支持通过接口(查询语音检测结果)主动轮询获取检测结果。</li>
-        <li>支持场景输入，包括：谩骂、色情、涉政等场景</li>
+        <li>支持场景输入，包括：谩骂、色情等场景</li>
         <li>支持批量提交检测任务。检测任务列表最多支持100个。</li>
         </br>
         <h4><b>音频文件限制说明：</b></h4>
@@ -415,10 +415,8 @@ class GmeClient(AbstractClient):
         <td>
         <p>normal:正常文本</p>
         <p>porn:色情</p>
-        <p>politics:涉政</p>
         <p>abuse:谩骂</p>
         <p>ad :广告</p>
-        <p>terrorism:暴恐</p>
         <p>contraband :违禁</p>
         <p>customized:自定义词库。目前白名单开放，如有需要请<a href="https://cloud.tencent.com/apply/p/8809fjcik56">联系我们</a>。</p>
         </td>
