@@ -35,6 +35,9 @@ FAILEDOPERATION_DEVICEOFFLINE = 'FailedOperation.DeviceOffline'
 # 存在其他升级任务。
 FAILEDOPERATION_OTHERUPDATETASKEXIST = 'FailedOperation.OtherUpdateTaskExist'
 
+# 产品尚未发布。
+FAILEDOPERATION_PRODUCTNOTRELEASED = 'FailedOperation.ProductNotReleased'
+
 # 转发已经停止。
 FAILEDOPERATION_RULEALREADYDISABLED = 'FailedOperation.RuleAlreadyDisabled'
 
@@ -101,6 +104,9 @@ INVALIDPARAMETERVALUE_DEVICEALREADYEXIST = 'InvalidParameterValue.DeviceAlreadyE
 # 设备名称非法。
 INVALIDPARAMETERVALUE_DEVICENAMEINVALID = 'InvalidParameterValue.DeviceNameInvalid'
 
+# 设备不存在。
+INVALIDPARAMETERVALUE_DEVICENOTEXIST = 'InvalidParameterValue.DeviceNotExist'
+
 # 任务不存在。
 INVALIDPARAMETERVALUE_ERRORTASKNOTEXIST = 'InvalidParameterValue.ErrorTaskNotExist'
 
@@ -221,6 +227,12 @@ INVALIDPARAMETERVALUE_VPNPARMSERROR = 'InvalidParameterValue.VPNParmsError'
 # 应用数量超出限制。
 LIMITEXCEEDED_APPLICATIONEXCEEDLIMIT = 'LimitExceeded.ApplicationExceedLimit'
 
+# 量产超出限制。
+LIMITEXCEEDED_BATCHPRODUCTIONEXCEEDLIMIT = 'LimitExceeded.BatchProductionExceedLimit'
+
+# 量产为空。
+LIMITEXCEEDED_BATCHPRODUCTIONNULL = 'LimitExceeded.BatchProductionNull'
+
 # 设备数量超过限制。
 LIMITEXCEEDED_DEVICEEXCEEDLIMIT = 'LimitExceeded.DeviceExceedLimit'
 
@@ -248,6 +260,15 @@ LIMITEXCEEDED_THINGMODELEXCEEDLIMIT = 'LimitExceeded.ThingModelExceedLimit'
 # 物模型事件 Type 错误。
 MISSINGPARAMETER_MODELDEFINEEVENTTYPEERROR = 'MissingParameter.ModelDefineEventTypeError'
 
+# 已有量产进行，请等待量产完成。
+RESOURCEINSUFFICIENT_BATCHPRODUCTIONISRUNNING = 'ResourceInsufficient.BatchProductionIsRunning'
+
+# 量产不存在。
+RESOURCENOTFOUND_BATCHPRODUCTIONNOTEXIST = 'ResourceNotFound.BatchProductionNotExist'
+
+# 上传URL无法获取。
+RESOURCENOTFOUND_CANNOTGETFROMURL = 'ResourceNotFound.CannotGetFromUrl'
+
 # 存在重复设备。
 RESOURCENOTFOUND_DEVICEDUPKEYEXIST = 'ResourceNotFound.DeviceDupKeyExist'
 
@@ -326,6 +347,9 @@ UNAUTHORIZEDOPERATION_DEVICEISNOTENABLED = 'UnauthorizedOperation.DeviceIsNotEna
 # 该设备下仍有绑定的设备。
 UNAUTHORIZEDOPERATION_GATEWAYHASBINDEDDEVICES = 'UnauthorizedOperation.GatewayHasBindedDevices'
 
+# 此家庭无权操作。
+UNAUTHORIZEDOPERATION_NOPERMISSIONTOFAMILY = 'UnauthorizedOperation.NoPermissionToFamily'
+
 # 实例ACL错误。
 UNAUTHORIZEDOPERATION_NOPERMISSIONTOINSTANCE = 'UnauthorizedOperation.NoPermissionToInstance'
 
