@@ -203,6 +203,9 @@ INVALIDPARAMETERVALUE_APMCONFIGINSTANCEID = 'InvalidParameterValue.ApmConfigInst
 # ApmConfigRegion参数传入错误。
 INVALIDPARAMETERVALUE_APMCONFIGREGION = 'InvalidParameterValue.ApmConfigRegion'
 
+# Args 参数值有误。
+INVALIDPARAMETERVALUE_ARGS = 'InvalidParameterValue.Args'
+
 # 函数异步重试配置参数无效。
 INVALIDPARAMETERVALUE_ASYNCTRIGGERCONFIG = 'InvalidParameterValue.AsyncTriggerConfig'
 
@@ -236,6 +239,9 @@ INVALIDPARAMETERVALUE_CODESECRET = 'InvalidParameterValue.CodeSecret'
 # CodeSource传入错误。
 INVALIDPARAMETERVALUE_CODESOURCE = 'InvalidParameterValue.CodeSource'
 
+# Command[Entrypoint] 参数值有误。
+INVALIDPARAMETERVALUE_COMMAND = 'InvalidParameterValue.Command'
+
 # CompatibleRuntimes参数传入错误。
 INVALIDPARAMETERVALUE_COMPATIBLERUNTIMES = 'InvalidParameterValue.CompatibleRuntimes'
 
@@ -269,6 +275,9 @@ INVALIDPARAMETERVALUE_DEFAULTNAMESPACE = 'InvalidParameterValue.DefaultNamespace
 # Description传入错误。
 INVALIDPARAMETERVALUE_DESCRIPTION = 'InvalidParameterValue.Description'
 
+# 环境变量DNS[OS_NAMESERVER]配置有误。
+INVALIDPARAMETERVALUE_DNSINFO = 'InvalidParameterValue.DnsInfo'
+
 # EipConfig参数错误。
 INVALIDPARAMETERVALUE_EIPCONFIG = 'InvalidParameterValue.EipConfig'
 
@@ -317,6 +326,9 @@ INVALIDPARAMETERVALUE_HANDLER = 'InvalidParameterValue.Handler'
 # IdleTimeOut参数传入错误。
 INVALIDPARAMETERVALUE_IDLETIMEOUT = 'InvalidParameterValue.IdleTimeOut'
 
+# imageUri 传入有误。
+INVALIDPARAMETERVALUE_IMAGEURI = 'InvalidParameterValue.ImageUri'
+
 # InlineZipFile非法。
 INVALIDPARAMETERVALUE_INLINEZIPFILE = 'InvalidParameterValue.InlineZipFile'
 
@@ -383,6 +395,9 @@ INVALIDPARAMETERVALUE_PUBLICNETCONFIG = 'InvalidParameterValue.PublicNetConfig'
 # 不支持的函数版本。
 INVALIDPARAMETERVALUE_QUALIFIER = 'InvalidParameterValue.Qualifier'
 
+# 企业版镜像实例ID[RegistryId]传值错误。
+INVALIDPARAMETERVALUE_REGISTRYID = 'InvalidParameterValue.RegistryId'
+
 # RetCode不合法。
 INVALIDPARAMETERVALUE_RETCODE = 'InvalidParameterValue.RetCode'
 
@@ -629,6 +644,9 @@ RESOURCENOTFOUND_QUALIFIER = 'ResourceNotFound.Qualifier'
 # 角色不存在。
 RESOURCENOTFOUND_ROLE = 'ResourceNotFound.Role'
 
+# Role不存在。
+RESOURCENOTFOUND_ROLECHECK = 'ResourceNotFound.RoleCheck'
+
 # Timer不存在。
 RESOURCENOTFOUND_TIMER = 'ResourceNotFound.Timer'
 
@@ -695,8 +713,14 @@ UNSUPPORTEDOPERATION_CDN = 'UnsupportedOperation.Cdn'
 # Cos操作不支持。
 UNSUPPORTEDOPERATION_COS = 'UnsupportedOperation.Cos'
 
+# 指定的配置EipFixed暂不支持。
+UNSUPPORTEDOPERATION_EIPFIXED = 'UnsupportedOperation.EipFixed'
+
 # 不支持此地域。
 UNSUPPORTEDOPERATION_REGION = 'UnsupportedOperation.Region'
 
 # Trigger操作不支持。
 UNSUPPORTEDOPERATION_TRIGGER = 'UnsupportedOperation.Trigger'
+
+# 指定的配置VpcConfig暂不支持。
+UNSUPPORTEDOPERATION_VPCCONFIG = 'UnsupportedOperation.VpcConfig'
