@@ -20,6 +20,9 @@ AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 创建vpc绑定关系失败。
+FAILEDOPERATION_CREATEBINDVPC = 'FailedOperation.CreateBindVpc'
+
 # 创建集群失败。
 FAILEDOPERATION_CREATECLUSTER = 'FailedOperation.CreateCluster'
 
@@ -71,9 +74,6 @@ FAILEDOPERATION_DELETESUBSCRIPTIONS = 'FailedOperation.DeleteSubscriptions'
 # 主题删除失败。
 FAILEDOPERATION_DELETETOPICS = 'FailedOperation.DeleteTopics'
 
-# 查询生产者数据失败。
-FAILEDOPERATION_DESCRIBEPRODUCERS = 'FailedOperation.DescribeProducers'
-
 # 查询订阅数据失败。
 FAILEDOPERATION_DESCRIBESUBSCRIPTION = 'FailedOperation.DescribeSubscription'
 
@@ -83,6 +83,12 @@ FAILEDOPERATION_GETENVIRONMENTATTRIBUTESFAILED = 'FailedOperation.GetEnvironment
 # 获取主题分区数失败。
 FAILEDOPERATION_GETTOPICPARTITIONSFAILED = 'FailedOperation.GetTopicPartitionsFailed'
 
+# 最大消息超过1MB。
+FAILEDOPERATION_MAXMESSAGESIZEERROR = 'FailedOperation.MaxMessageSizeError'
+
+# 上传的msgID错误。
+FAILEDOPERATION_MESSAGEIDERROR = 'FailedOperation.MessageIDError'
+
 # 必须先清除关联命名空间才能继续操作。
 FAILEDOPERATION_NAMESPACEINUSE = 'FailedOperation.NamespaceInUse'
 
@@ -101,6 +107,9 @@ FAILEDOPERATION_ROLEINUSE = 'FailedOperation.RoleInUse'
 # 保存秘钥失败。
 FAILEDOPERATION_SAVESECRETKEY = 'FailedOperation.SaveSecretKey'
 
+# 消息发送超时。
+FAILEDOPERATION_SENDMESSAGETIMEOUTERROR = 'FailedOperation.SendMessageTimeoutError'
+
 # 发送消息失败。
 FAILEDOPERATION_SENDMSGFAILED = 'FailedOperation.SendMsgFailed'
 
@@ -110,6 +119,9 @@ FAILEDOPERATION_SETTTL = 'FailedOperation.SetTTL'
 # 必须先清除关联主题数据才能继续操作。
 FAILEDOPERATION_TOPICINUSE = 'FailedOperation.TopicInUse'
 
+# 请使用partition topic。
+FAILEDOPERATION_TOPICTYPEERROR = 'FailedOperation.TopicTypeError'
+
 # 环境更新失败。
 FAILEDOPERATION_UPDATEENVIRONMENT = 'FailedOperation.UpdateEnvironment'
 
@@ -125,12 +137,18 @@ FAILEDOPERATION_UPDATETOPIC = 'FailedOperation.UpdateTopic'
 # 必须先清除关联VPC路由数据才能继续操作。
 FAILEDOPERATION_VPCINUSE = 'FailedOperation.VpcInUse'
 
+# 内部错误。
+INTERNALERROR = 'InternalError'
+
 # Broker服务异常。
 INTERNALERROR_BROKERSERVICE = 'InternalError.BrokerService'
 
 # 获取属性失败。
 INTERNALERROR_GETATTRIBUTESFAILED = 'InternalError.GetAttributesFailed'
 
+# 内部错误。
+INTERNALERROR_ILLEGALMESSAGE = 'InternalError.IllegalMessage'
+
 # 重试可以成功。
 INTERNALERROR_RETRY = 'InternalError.Retry'
 
@@ -164,6 +182,9 @@ INVALIDPARAMETERVALUE_TTL = 'InvalidParameterValue.TTL'
 # 上传的topic name错误。
 INVALIDPARAMETERVALUE_TOPICNOTFOUND = 'InvalidParameterValue.TopicNotFound'
 
+# 超过配额限制。
+LIMITEXCEEDED = 'LimitExceeded'
+
 # 实例下集群数量超过限制。
 LIMITEXCEEDED_CLUSTERS = 'LimitExceeded.Clusters'
 
@@ -191,6 +212,9 @@ OPERATIONDENIED_CONSUMERRUNNING = 'OperationDenied.ConsumerRunning'
 # 默认环境不允许操作。
 OPERATIONDENIED_DEFAULTENVIRONMENT = 'OperationDenied.DefaultEnvironment'
 
+# 资源被占用。
+RESOURCEINUSE = 'ResourceInUse'
+
 # 集群已存在。
 RESOURCEINUSE_CLUSTER = 'ResourceInUse.Cluster'
 
@@ -200,6 +224,9 @@ RESOURCEINUSE_ENVIRONMENTROLE = 'ResourceInUse.EnvironmentRole'
 # 重名，命名空间已存在。
 RESOURCEINUSE_NAMESPACE = 'ResourceInUse.Namespace'
 
+# 队列已存在。
+RESOURCEINUSE_QUEUE = 'ResourceInUse.Queue'
+
 # 角色已存在。
 RESOURCEINUSE_ROLE = 'ResourceInUse.Role'
 
@@ -209,6 +236,12 @@ RESOURCEINUSE_SUBSCRIPTION = 'ResourceInUse.Subscription'
 # 重名，主题已存在。
 RESOURCEINUSE_TOPIC = 'ResourceInUse.Topic'
 
+# 资源不足。
+RESOURCEINSUFFICIENT = 'ResourceInsufficient'
+
+# 资源不存在。
+RESOURCENOTFOUND = 'ResourceNotFound'
+
 # 服务的集群不存在。
 RESOURCENOTFOUND_BROKERCLUSTER = 'ResourceNotFound.BrokerCluster'
 
@@ -236,6 +269,9 @@ RESOURCENOTFOUND_TOPIC = 'ResourceNotFound.Topic'
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
+# 发货异常。
+RESOURCEUNAVAILABLE_CREATEFAILED = 'ResourceUnavailable.CreateFailed'
+
 # 系统升级。
 RESOURCEUNAVAILABLE_SYSTEMUPGRADE = 'ResourceUnavailable.SystemUpgrade'
 
